/*
Copyright (C) 2001  Sensoray Co., Inc.  This program is free software;
you can redistribute it and/or modify it under the terms of the GNU
General Public License as published by the Free Software Foundation;
either version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA

In addition, as a special exception, Sensoray Co., Inc., gives permission
to link the code of this program with the 'x12cnt.o' library (or with
modified versions of x12cnt.o that use the same license as 'x12cnt.o'),
and distribute linked combinations including the two. You must obey the
GNU General Public License in all respects for all of the code used other
than 'x12cnt.o'. If you modify this file, you may extend this exception
to your version of the file, but you are not obligated to do so. If you
do not wish to do so, delete this exception statement from your version.
*/

#ifndef __X12GBL__
#define __X12GBL__

// just a build number...
#define BUILD 47

#include "sx12.h"


/**********************************************/
/* System constants                           */
/**********************************************/

/**********************************************/
/* Maximum number or 512s allowed in system   */
/*       NEVER MODIFY THIS VALUE!             */
#define MAX_CARDS 4
/**********************************************/

/**********************************************/
/* Size (bytes) of kernel space MPEG buffer   */
/* May be modified to improve performance     */
#define MAX_BUF 65536
/**********************************************/

/**********************************************/
/* Char device major number                   */
/* May be modified with caution. Only modify  */
/* major number if this number is already     */
/* being used by another device.              */
#define X12_MAJOR 122
/**********************************************/


/**********************************************/
/* The VPAR Data structure                    */
/*                                            */
/* A pointer to a VPAR data structure is      */
/* obtatined by calling the Initialize()      */
/* function.                                  */
/*                                            */
/* NOTE: Any changes to the structure's       */
/*       members will only be registered and  */
/*       take effect when a call to either    */
/*       Reset(), StartEncode(), StartDecode()*/
/*       is made.                             */
/**********************************************/
typedef struct
{
    short  input;        /* video input                                      */
    short  inputtype;    /* for composite video set to 0,for S-Video set to 1*/
    short  base_addr;    /* 512 i/o address.Do not modify,set by Initialize()*/
    long   pic_size;     /* Set picture size and compression system with the */
                         /* following values (default is 0):                 */
                         /* 0 - D1, MPEG-2, NTSC-704x480, PAL-704x576        */
                         /* 1 - 1/2 D1, MPEG-2, NTSC-352x480, PAL-352x576    */
                         /* 2 - 2/3 D1, MPEG-2, NTSC-480x480, PAL-480x576    */
                         /* 3 - CIF, MPEG-1, NTSC-352x240, PAL-352x288       */
    long   N;            /* number of frames in Group of Pictures            */
                         /* (default is 15)                                  */
    long   M;            /* distance between I/P frames (default is 3)       */
    double bit_rate;	 /* bits per second (default is 4,000,000)           */
    long   video_system; /* for PAL set to 1, for NTSC set to 2              */
    long   VBR_on;       /* Enables(1)/disables variable bit rate compression*/
                         /* (default is 0, disabled)                         */
    short  debug;        /* Enables SM2210 debug messages (default is 0, off)*/
} VPAR;



/******************************/
/* x12cnt.o library functions */
/******************************/

/*****************************************************************************/
/* Function: StartEncode()                                                   */
/* Description: Starts the MPEG encoding process                             */
/* Arguments: CardId - selects the 512 board. 0-first 512, 1-second 512, etc.*/
/* Return value: 0-Success, -1-Timed out                                     */
/*****************************************************************************/
short StartEncode(unsigned short CardId);

/*****************************************************************************/
/* Function: StartDecode()                                                   */
/* Description: Starts the MPEG decoding process                             */
/* Arguments: CardId - selects the 512 board. 0-first 512, 1-second 512, etc.*/
/* Return value: 0-Success, -1-Timed out                                     */
/*****************************************************************************/
short StartDecode(unsigned short CardId);

/*****************************************************************************/
/* Function: WriteStream()                                                   */
/* Description: Writes MPEG data to the decoder                              */
/* Arguments: CardId - selects the 512 board. 0-first 512, 1-second 512, etc.*/
/*            StreamBuffer - Pointer to source MPEG data buffer              */
/*            Length - desired number of bytes to be written                 */
/* Return value: number of bytes actually written and could be zero          */
/*****************************************************************************/
unsigned long WriteStream(unsigned short CardId,
			  unsigned short *StreamBuffer,
			  unsigned long Length);

/*****************************************************************************/
/* Function: ReadStream()                                                    */
/* Description: Reads MPEG data from the encoder                             */
/* Arguments: CardId - selects the 512 board. 0-first 512, 1-second 512, etc.*/
/*            StreamBuffer - Pointer to destination MPEG data buffer         */
/*            Length - desired number of bytes to be read                    */
/* Return value: number of bytes actually read and could be zero             */
/*****************************************************************************/
unsigned long ReadStream(unsigned short CardId,
			 unsigned short *StreamBuffer,
			 unsigned long Length);

/*****************************************************************************/
/* Function: ReadGPIO()                                                      */
/* Description: Reads the state of the digital I/O pins                      */
/* Arguments: CardId - selects the 512 board. 0-first 512, 1-second 512, etc.*/
/* Return value: State of I/Os. Bits 3-15 are 0s', bit 0 gives the state of  */
/*               DIO0, bit 1 the state of DIO1, and bit 2 the state of DIO2. */
/*****************************************************************************/
short ReadGPIO(unsigned short CardId);

/*****************************************************************************/
/* Function: WriteGPIO()                                                     */
/* Description: Writes to the digital I/O pins and sets them to in- or output*/
/* Arguments: CardId - selects the 512 board. 0-first 512, 1-second 512, etc.*/
/*            out - Bit 0 sets the level of DIO0, bit 1 of DIO1 and bit 2    */
/*                  of DIO2. These will only take effect if the corresponding*/
/*                  bit is set as output.                                    */
/*            dir - Setting bit 0 to 1 makes DIO0 an output, setting bit 0   */
/*                  to 0 makes DIO0 an input. The same applies for the other */
/*                  two bits. HINT: To create an 'open collector' type output*/
/*                  set the desired output bit to zero and then use this bit */
/*                  to turn the output on and off.                           */
/* Return value: Nothing                                                     */
/*****************************************************************************/
void WriteGPIO(unsigned short CardId, unsigned short out, unsigned short dir);

/*****************************************************************************/
/* Function: Reset()                                                         */
/* Description: Resets the 512 using the current video settings (i.e. current*/
/*              input, input type, and video system)                         */
/* Arguments: CardId - selects the 512 board. 0-first 512, 1-second 512, etc.*/
/* Return value: 0-Success, -1-512 not responding                            */
/*****************************************************************************/
short Reset(unsigned short CardId);

/*****************************************************************************/
/* Function: Initialize()                                                    */
/* Description: Initializes the 512 and obtains a pointer to the VPAR        */
/*              structure.                                                   */
/* Arguments: CardId - selects the 512 board. 0-first 512, 1-second 512, etc.*/
/*            base - The i/o base address of the 512. If default jumper      */
/*                   are used this would be 0xcc0.                           */
/*            system - Video system. For PAL set to 1, for NTSC set to 2     */
/*            intype - Input type. For composite video set to 0, for S-Video */
/*                     set to 1                                              */
/*            inno - Video input selector                                    */
/*                                                                           */
/*            *** the following arguments are for passing kernel globals     */
/*                to the driver ***                                          */
/*                                                                           */
/*            kj   - must be pointer to 'jiffies', i.e. set to &jiffies      */
/*            kp   - must be pointer to 'printk', i.e. set to printk         */
/*            kj   - must be pointer to 'schedule', i.e. set to schedule     */
/*            hz   - set to HZ contant                                       */
/*                                                                           */
/*            *** Video queue threshholds                                    */
/*                                                                           */
/*            vq_high_level - when the 512 video queue is below this value   */
/*                            MPEG data can be written to the 512. If set to */
/*                            zero the default value of 0xC000 is used.      */
/*                            You can change this value but be careful!      */
/*                                                                           */
/*            vq_low_level  - when the 512 video queue has exceeded this     */
/*                            the 512 can read MPEG data. If set to zero     */
/*                            the default value of 0x4000 is used. You can   */
/*                            change this value but be careful!              */
/*                                                                           */
/*       e.g. Initialize(0,0xcc0,2,0,1,&jiffies,printk,schedule,HZ,0,0);     */
/*                                                                           */
/* Return value: Pointer to a VPAR structure                                 */
/*****************************************************************************/
//typedef int (*KP)(char *,int,int,int,int);
typedef int (*KP)(const char *, ...);
typedef void (*KS)(void);

VPAR *Initialize(unsigned short CardId, unsigned short base,
                 unsigned short system, unsigned short intype,
                 unsigned short inno, unsigned long volatile *kj,
                 KP kp, KS ks, unsigned long hz, unsigned long vq_high_level,
				 unsigned long vq_low_level);

/*****************************************************************************/
/* Function: GetDroppedFrames()                                              */
/* Description: Returns the number of frames that were dropped during        */
/*              compression                                                  */
/* Arguments: CardId - selects the 512 board. 0-first 512, 1-second 512, etc.*/
/* Return value: Number of frames dropped                                    */
/*****************************************************************************/
unsigned long GetDroppedFrames(unsigned short CardId);

/*****************************************************************************/
/* Function: GetFrameCount()                                                 */
/* Description: Returns the number of frames compressed                      */
/* Arguments: CardId - selects the 512 board. 0-first 512, 1-second 512, etc.*/
/* Return value: Number of frames compressed                                 */
/*****************************************************************************/
unsigned long GetFrameCount(unsigned short CardId);

/*****************************************************************************/
/* Function: GetBitCount()                                                   */
/* Description: Returns the number of bits compressed                        */
/* Arguments: CardId - selects the 512 board. 0-first 512, 1-second 512, etc.*/
/* Return value: Number of bits compressed                                   */
/*****************************************************************************/
unsigned long GetBitCount(unsigned short CardId);

/*****************************************************************************/
/* Function: GetDisplayFrameCount()                                          */
/* Description: Returns the number of frames decompressed                    */
/* Arguments: CardId - selects the 512 board. 0-first 512, 1-second 512, etc.*/
/* Return value: Number of frames decompressed                               */
/*****************************************************************************/
unsigned long GetDisplayFrameCount(unsigned short CardId);

/*****************************************************************************/
/* Function: GetVQSize()                                                     */
/* Description: Returns the amount of MPEG data in the video queue           */
/* Arguments: CardId - selects the 512 board. 0-first 512, 1-second 512, etc.*/
/* Return value: A number indicating the fullness of the video queue         */
/*****************************************************************************/
unsigned long GetVQSize(unsigned short CardId);

/*****************************************************************************/
/***IMPORTANT THIS FUNCTION USES A SPECIAL FEATURE OF THE SENSORAY 301 CPU****/
/***AND IS NOT FUNCTIONAL WITH OTHER CPUs.                                ****/
/*****************************************************************************/
/* Function:  ReadNextHeader                                                 */
/* Parameters: CardId - card number                                          */
/*             StreamBuffer - buffer to place MPEG data                      */
/*             MaxLength - length of buffer in bytes (multiple of 8)         */
/*             RetLength - Actual length of data obtained                    */
/* Returns:    Zero when end of header has not been reached. Non-zero        */
/*             when end of header reached.                                   */
/* Description: This function reads a MPEG data header block from the MPEG   */
/*              encoder                                                      */
/*****************************************************************************/
long ReadNextHeader(unsigned short CardId, unsigned short *StreamBuffer,
                             int MaxLength, int *RetLength);

/*****************************************************************************/
/* Function:  GetInputVideoFID                                               */
/* Parameters: CardId - card number                                          */
/* Returns:   Toggles between zero and non-zero for each field               */
/* Description: Returns the current input video field id.                    */
/*****************************************************************************/
short GetInputVideoFID(unsigned short CardId);

/*****************************************************************************/
/* Function:  VideoInputControl                                              */
/* Parameters: CardId - card number                                          */
/*             on     - when non-zero video source is on                     */
/* Returns:   Nothing                                                        */
/* Description: Turns video source into SM on or off.                        */
/*****************************************************************************/
void VideoInputControl(unsigned short CardId, short on);

#endif


